"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
// @ts-nocheck
require("./element-highlight.css");
const react_1 = require("react");
const useCapture = true;
const activeClassName = "contenteditable-element-selector-active";
const ElementHighlight = ({ applicationRootElement, isActiveRef, onSelect, }) => {
    (0, react_1.useEffect)(() => {
        const mouseOutCallback = (event) => {
            const target = event.target;
            if (!applicationRootElement.contains(target))
                return;
            target.classList.remove("contenteditable-element-hover");
        };
        const mouseOverCallback = (event) => {
            const target = event.target;
            if (!isActiveRef || !isActiveRef.current)
                return;
            if (!applicationRootElement.contains(target))
                return;
            target.classList.add("contenteditable-element-hover");
        };
        const mouseClickCallback = (event) => {
            const target = event.target;
            if (!isActiveRef || !isActiveRef.current)
                return;
            if (!applicationRootElement.contains(target))
                return;
            event.preventDefault();
            event.stopPropagation();
            const selected = document.querySelector(".contenteditable-element-seleted");
            if (selected)
                selected.classList.remove("contenteditable-element-seleted");
            target.classList.add("contenteditable-element-seleted");
            onSelect(target);
        };
        window.addEventListener("mouseout", mouseOutCallback, useCapture);
        window.addEventListener("mouseover", mouseOverCallback, useCapture);
        window.addEventListener("click", mouseClickCallback, useCapture);
        return () => {
            window.removeEventListener("mouseout", mouseOutCallback, useCapture);
            window.removeEventListener("mouseover", mouseOverCallback, useCapture);
            window.removeEventListener("click", mouseClickCallback, useCapture);
        };
    }, []);
    (0, react_1.useEffect)(() => {
        if (isActiveRef && isActiveRef.current) {
            const propKey = isActiveRef.current ? "add" : "remove";
            window.document.body.classList[propKey](activeClassName);
        }
        return () => {
            window.document.body.classList.remove(activeClassName);
        };
    }, [isActiveRef && isActiveRef.current]);
    return null;
};
exports.default = ElementHighlight;
